You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@accumulo.apache.org by ct...@apache.org on 2020/06/10 16:52:49 UTC

[accumulo] branch master updated: Use more neutral language for banned item list

This is an automated email from the ASF dual-hosted git repository.

ctubbsii pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/accumulo.git


The following commit(s) were added to refs/heads/master by this push:
     new ef149d4  Use more neutral language for banned item list
ef149d4 is described below

commit ef149d41f0d5f00ebd381394ef37bbd2cc21f9b5
Author: Christopher Tubbs <ct...@apache.org>
AuthorDate: Wed Jun 10 12:50:38 2020 -0400

    Use more neutral language for banned item list
    
    Rename 'blacklist' variable to the more neutral 'banList' to avoid the
    unnecessarily negative association between 'black' and 'bad'.
---
 start/src/main/java/org/apache/accumulo/start/Main.java | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/start/src/main/java/org/apache/accumulo/start/Main.java b/start/src/main/java/org/apache/accumulo/start/Main.java
index e147106..6e04a72 100644
--- a/start/src/main/java/org/apache/accumulo/start/Main.java
+++ b/start/src/main/java/org/apache/accumulo/start/Main.java
@@ -238,16 +238,16 @@ public class Main {
 
   public static Map<String,KeywordExecutable>
       checkDuplicates(final Iterable<? extends KeywordExecutable> services) {
-    TreeSet<String> blacklist = new TreeSet<>();
+    TreeSet<String> banList = new TreeSet<>();
     TreeMap<String,KeywordExecutable> results = new TreeMap<>();
     for (KeywordExecutable service : services) {
       String keyword = service.keyword();
-      if (blacklist.contains(keyword)) {
+      if (banList.contains(keyword)) {
         // subsequent times a duplicate is found, just warn and exclude it
         warnDuplicate(service);
       } else if (results.containsKey(keyword)) {
-        // the first time a duplicate is found, blacklist it and warn
-        blacklist.add(keyword);
+        // the first time a duplicate is found, banList it and warn
+        banList.add(keyword);
         warnDuplicate(results.remove(keyword));
         warnDuplicate(service);
       } else {